@@ -27,10 +27,13 @@ FQDN = socket.getfqdn()
 
 
 class Backup(object):
-    def __init__(self, auth_url, username, password, container_name=FQDN):
+    def __init__(self, auth_url, username, password,
+                 verify=True, container_name=FQDN):
+        self.verify = verify
         self.token, self.storage_url = client.retrieve_token(auth_url,
                                                              username,
-                                                             password)
+                                                             password,
+                                                             self.verify)
         self.container_name = container_name
 
     def backup(self, target_path):
@@ -54,20 +57,22 @@ class Backup(object):
         object_name = os.path.basename(filename)
 
         if not client.is_container(self.token, self.storage_url,
-                                   self.container_name):
+                                   self.container_name, self.verify):
             # False is no container
             rc = client.create_container(self.token,
                                          self.storage_url,
-                                         self.container_name)
+                                         self.container_name,
+                                         self.verify)
             if not (rc == 201 or rc == 202):
                 # 201; Created, 202; Accepted
                 raise RuntimeError('Failed to create the container "%s"'
-                                   % self.container_name)
+                                   % self.container_name, self.verify)
 
         objects_list = [object.get('name') for object in
                         client.list_objects(self.token,
                                             self.storage_url,
-                                            self.container_name)]
+                                            self.container_name,
+                                            self.verify)]
 
         if object_name in objects_list:
             self.rotate(filename, object_name, objects_list)
@@ -75,7 +80,8 @@ class Backup(object):
             rc = client.create_object(self.token,
                                       self.storage_url,
                                       self.container_name,
-                                      filename)
+                                      filename,
+                                      self.verify)
             if not (rc == 201 or rc == 202):
                 raise RuntimeError('Failed to create the object "%s"'
                                    % object_name)
@@ -95,14 +101,14 @@ class Backup(object):
         timestamp = datetime.now().strftime("%Y%m%d-%H%M%S")
         new_object_name = object_name + '_' + timestamp
         rc = client.copy_object(self.token, self.storage_url,
-                                self.container_name,
-                                object_name, new_object_name)
+                                self.container_name, object_name,
+                                new_object_name, self.verify)
         if rc != 201:
             raise RuntimeError('Failed to copy object "%s"' % new_object_name)
 
         # create new object
         rc = client.create_object(self.token, self.storage_url,
-                                  self.container_name, filename)
+                                  self.container_name, filename, self.verify)
         if rc != 201:
             raise RuntimeError('Failed to create the object "%s"'
                                % object_name)
@@ -112,7 +118,7 @@ class Backup(object):
                         if obj.startswith(object_name + '_')]
         archive_list.reverse()
         [client.delete_object(self.token, self.storage_url,
-                              self.container_name, obj)
+                              self.container_name, obj, self.verify)
          for i, obj in enumerate(archive_list) if i + 1 > rotate_limit - 1]
         return True
 
@@ -123,18 +129,20 @@ class Backup(object):
             verbose: boolean flag of listing objects
         """
         if not client.is_container(self.token, self.storage_url,
-                                   self.container_name):
+                                   self.container_name, self.verify):
             return []
 
         if verbose:
             backup_l = [i for i in client.list_objects(self.token,
                                                        self.storage_url,
-                                                       self.container_name)]
+                                                       self.container_name,
+                                                       self.verify)]
         else:
             backup_l = [i.get('name') for i
                         in client.list_objects(self.token,
                                                self.storage_url,
-                                               self.container_name)]
+                                               self.container_name,
+                                               self.verify)]
         return backup_l
 
     def retrieve_backup_data(self, object_name, output_filepath=None):
@@ -144,13 +152,14 @@ class Backup(object):
             object_name: delete target object name
         """
         if (client.is_container(self.token, self.storage_url,
-                                self.container_name) and
+                                self.container_name, self.verify) and
             client.is_object(self.token, self.storage_url,
-                             self.container_name, object_name)):
+                             self.container_name, object_name, self.verify)):
             rc, content = client.retrieve_object(self.token,
                                                  self.storage_url,
                                                  self.container_name,
-                                                 object_name)
+                                                 object_name,
+                                                 self.verify)
             if not rc:
                 raise RuntimeError('Failed to retrieve the object "%s"'
                                    % object_name)
@@ -174,13 +183,14 @@ class Backup(object):
             object_name: delete target object name
         """
         if (client.is_container(self.token, self.storage_url,
-                                self.container_name) and
+                                self.container_name, self.verify) and
             client.is_object(self.token, self.storage_url,
-                             self.container_name, object_name)):
+                             self.container_name, object_name, self.verify)):
             rc = client.delete_object(self.token,
                                       self.storage_url,
                                       self.container_name,
-                                      object_name)
+                                      object_name,
+                                      self.verify)
             if not rc == 204:
                 raise RuntimeError('Failed to delete the object "%s"'
                                    % object_name)
